Changelog
=========


0.10.0 (2017-01-20)
-------------------

- BREAKING: Submenus are now created inside the menu <li> element, instead of after the whole <ul> [pnicolli]


0.9.1 (2016-12-02)
------------------

- Added Dexterity support for the static portion of the menu [pnicolli]
- Page template now loaded inside the class to allow easier viewlet cloning [pnicolli]
- Add simple "not expansible" link in menu [lucabel]
- Add possibility to condition tab visibility the same way portal_tabs did it [lucabel]
- Add Plone5 compatibility (no resourse registry)
  [cekk]


0.9.0 (2016-03-15)
------------------

- Fix MANIFEST.in and trove classifiers in order to release package on PyPI
  [ale-rt]


0.2.1 (2016-01-11)
------------------

- Fix js call [cekk]


0.2.0 (2016-01-11)
------------------

- Fix registry problems [cekk]


0.1.0 (2016-01-05)
------------------

- Initial release.
  [cekk]
